@@ -1,5 +1,4 @@
 # @author Augustin Mortier
-# @email augustinm@met.no
 # @desc A-Profiles - Image plot
 
 import matplotlib.pyplot as plt
@@ -38,7 +37,7 @@ def _plot_foc(da, zref):
                 alpha=0.4,
             )
     # plot markers
-    plt.plot([], [], "^m", ms=10, lw=0, label="foc or condensation")
+    plt.plot([], [], "^m", ms=10, lw=0, label="fog or condensation")
     plt.plot(time, foc_markers, "m", marker=10, ms=10, lw=0)
 
 
@@ -120,6 +119,8 @@ def plot(
     show_pbl=False,
     show_clouds=False,
     cmap="coolwarm",
+    show_fig=True,
+    save_fig = None
 ):
     """Plot image of selected variable from :class:`aprofiles.profiles.ProfilesData` object.
 
@@ -136,6 +137,8 @@ def plot(
         - show_pbl (bool, optional): Add PBL height. Defaults to `False`.
         - show_clouds (bool, optional): Add clouds detection. Defaults to `False`.
         - cmap (str, optional): Matplotlib colormap. Defaults to `'coolwarm'` cmap from seaborn.
+        - show_fig (bool, optional): Show Figure. Defaults to `True`.
+        - save_fig (str, optional): Path of the saved figure. Defaults to `None`.
 
     Example:
         >>> import aprofiles as apro
@@ -146,7 +149,7 @@ def plot(
         >>> # attenuated backscatter image
         >>> profiles.plot(vmin=1e-2, vmax=1e1, log=True)
 
-        .. figure:: ../../examples/images/attenuated_backscatter.png
+        .. figure:: ../../docs/_static/images/attenuated_backscatter.png
             :scale: 50 %
             :alt: attenuated backscatter profiles
 
@@ -230,4 +233,7 @@ def plot(
     cbar.set_label(label)
 
     plt.tight_layout()
-    plt.show()
+    if save_fig:
+        plt.savefig(save_fig)
+    if show_fig:
+        plt.show()
\ No newline at end of file
